*********************************************************************************************************************
/*Thyne, Clayton. 2012. 'Information, Commitment, and Intra-War Bargaining: The Effect of Governmental Constraints
on Civil War Duration.' International Studies Quarterly, 56:307-321*/
/*Appendix replication data*/
*********************************************************************************************************************

/*Table 1. Main results in the manuscript*/
use "thyne_ISQ_appendix_T1-5.dta", clear
	streg info_index lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg commitment_index lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg veto_index lenient lnbdead lngdppc fight_gov powthy_a lfor, d(w) nolog time robust
	streg xconst lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg eiec lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg polariz lenient lnbdead lngdppc fight_gov powthy_a lfor, d(w) nolog time robust
	streg parl_exc lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg parl_exc lenient lnbdead lngdppc fight_gov powthy_a lfor   if eiec>=6 & eiec~=., d(w) nolog time robust
	streg yrsoffc lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg prtyin lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust

/*Appendix Table 1: Cox model*/	
use "thyne_ISQ_appendix_T1-5.dta", clear
	stcox info_index lenient lnbdead lngdppc fight_gov powthy_a lfor , nolog nohr  robust
	stcox commitment_index lenient lnbdead lngdppc fight_gov powthy_a lfor , nolog nohr  robust
	stcox veto_index lenient lnbdead lngdppc fight_gov powthy_a lfor, nolog nohr  robust
	stcox xconst lenient lnbdead lngdppc fight_gov powthy_a lfor , nolog nohr  robust
	stcox eiec lenient lnbdead lngdppc fight_gov powthy_a lfor , nolog nohr  robust
	stcox polariz lenient lnbdead lngdppc fight_gov powthy_a lfor, nolog nohr  robust
	stcox parl_exc lenient lnbdead lngdppc fight_gov powthy_a lfor , nolog nohr  robust
	stcox parl_exc lenient lnbdead lngdppc fight_gov powthy_a lfor   if eiec>=6 & eiec~=., nolog nohr  robust
	stcox yrsoffc lenient lnbdead lngdppc fight_gov powthy_a lfor , nolog nohr  robust
	stcox prtyin lenient lnbdead lngdppc fight_gov powthy_a lfor , nolog nohr  robust

/*Appendix Table 2: Logit model*/
use "thyne_ISQ_appendix_T1-5.dta", clear	
btscs failure duration id2, gen(peace) nspline(3)	
	logit failure info_index lenient lnbdead lngdppc fight_gov powthy_a lfor peace _spline1 _spline2 _spline3, nolog robust
	logit failure commitment_index lenient lnbdead lngdppc fight_gov powthy_a lfor peace _spline1 _spline2 _spline3, nolog robust
	logit failure veto_index lenient lnbdead lngdppc fight_gov powthy_a lfor peace _spline1 _spline2 _spline3, nolog robust
	logit failure xconst lenient lnbdead lngdppc fight_gov powthy_a lfor peace _spline1 _spline2 _spline3, nolog robust
	logit failure eiec lenient lnbdead lngdppc fight_gov powthy_a lfor peace _spline1 _spline2 _spline3, nolog robust
	logit failure polariz lenient lnbdead lngdppc fight_gov powthy_a lfor peace _spline1 _spline2 _spline3, nolog robust
	logit failure parl_exc lenient lnbdead lngdppc fight_gov powthy_a lfor peace _spline1 _spline2 _spline3, nolog robust
	logit failure parl_exc lenient lnbdead lngdppc fight_gov powthy_a lfor peace _spline1 _spline2 _spline3  if eiec>=6 & eiec~=., nolog robust
	logit failure yrsoffc lenient lnbdead lngdppc fight_gov powthy_a lfor peace _spline1 _spline2 _spline3, nolog robust
	logit failure prtyin lenient lnbdead lngdppc fight_gov powthy_a lfor peace _spline1 _spline2 _spline3, nolog robust
	
/*Appendix Table 3: Excluding government victories*/
use "thyne_ISQ_appendix_T1-5.dta", clear	
gen fail2=failure
replace fail2=0 if vgov==1
stset duration, id(id2) failure(fail2==1)
	streg info_index lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg commitment_index lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg veto_index lenient lnbdead lngdppc fight_gov powthy_a lfor, d(w) nolog time robust
	streg xconst lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg eiec lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg polariz lenient lnbdead lngdppc fight_gov powthy_a lfor, d(w) nolog time robust
	streg parl_exc lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg parl_exc lenient lnbdead lngdppc fight_gov powthy_a lfor   if eiec>=6 & eiec~=., d(w) nolog time robust
	streg yrsoffc lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg prtyin lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
				
/*Appendix Table 4: Exclude all victories*/
use "thyne_ISQ_appendix_T1-5.dta", clear		
gen fail3=failure
replace fail3=0 if vany==1
stset duration, id(id2) failure(fail3==1)
	streg info_index lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg commitment_index lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg veto_index lenient lnbdead lngdppc fight_gov powthy_a lfor, d(w) nolog time robust
	streg xconst lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg eiec lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg polariz lenient lnbdead lngdppc fight_gov powthy_a lfor, d(w) nolog time robust
	streg parl_exc lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg parl_exc lenient lnbdead lngdppc fight_gov powthy_a lfor   if eiec>=6 & eiec~=., d(w) nolog time robust
	streg yrsoffc lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust
	streg prtyin lenient lnbdead lngdppc fight_gov powthy_a lfor , d(w) nolog time robust

/*Appendix Table 5: Exclude coups*/
use "thyne_ISQ_appendix_T1-5.dta", clear		
stset duration, id(id2) failure(failure==1)
	streg info_index lenient lnbdead lngdppc fight_gov  lfor if powthy~=1 , d(w) nolog time robust
	streg commitment_index lenient lnbdead lngdppc fight_gov  lfor if powthy~=1 , d(w) nolog time robust
	streg veto_index lenient lnbdead lngdppc fight_gov  lfor if powthy~=1, d(w) nolog time robust
	streg xconst lenient lnbdead lngdppc fight_gov  lfor if powthy~=1 , d(w) nolog time robust
	streg eiec lenient lnbdead lngdppc fight_gov  lfor if powthy~=1 , d(w) nolog time robust
	streg polariz lenient lnbdead lngdppc fight_gov  lfor if powthy~=1, d(w) nolog time robust
	streg parl_exc lenient lnbdead lngdppc fight_gov  lfor if powthy~=1 , d(w) nolog time robust
	streg parl_exc lenient lnbdead lngdppc fight_gov  lfor if powthy~=1  & eiec>=6 & eiec~=., d(w) nolog time robust
	streg yrsoffc lenient lnbdead lngdppc fight_gov  lfor if powthy~=1 , d(w) nolog time robust
	streg prtyin lenient lnbdead lngdppc fight_gov  lfor if powthy~=1 , d(w) nolog time robust
		
/*Appendix Table 6: Exclude short wars*/
use "thyne_ISQ_appendix_T6.dta", clear	
	streg info_index lenient lnbdead lngdppc fight_gov lfor, d(w) nolog time robust
	streg commitment_index lenient lnbdead lngdppc fight_gov  lfor, d(w) nolog time robust
	streg veto_index lenient lnbdead lngdppc fight_gov  lfor, d(w) nolog time robust
	streg xconst lenient lnbdead lngdppc fight_gov  lfor, d(w) nolog time robust
	streg eiec lenient lnbdead lngdppc fight_gov  lfor, d(w) nolog time robust
	streg polariz lenient lnbdead lngdppc fight_gov  lfor, d(w) nolog time robust
	streg parl_exc lenient lnbdead lngdppc fight_gov  lfor, d(w) nolog time robust
	streg parl_exc lenient lnbdead lngdppc fight_gov  lfor if eiec>=6 & eiec~=., d(w) nolog time robust
	streg yrsoffc lenient lnbdead lngdppc fight_gov  lfor, d(w) nolog time robust
	streg prtyin lenient lnbdead lngdppc fight_gov  lfor, d(w) nolog time robust
